@@ -1,9 +1,6 @@
 package Dist::Zilla::PluginBundle::RJBS;
-{
-  $Dist::Zilla::PluginBundle::RJBS::VERSION = '5.002';
-}
 # ABSTRACT: BeLike::RJBS when you build your dists
-
+$Dist::Zilla::PluginBundle::RJBS::VERSION = '5.003';
 use Moose;
 use Moose::Autobox;
 use Dist::Zilla 2.100922; # TestRelease
@@ -21,6 +18,7 @@ with 'Dist::Zilla::Role::PluginBundle::Easy';
 #   [Git::NextVersion]
 #   [PkgVersion]
 #   die_on_existing_version = 1
+#   die_on_line_insertion   = 1
 #   [MetaConfig]
 #   [MetaJSON]
 #   [NextRelease]
@@ -146,7 +144,12 @@ sub configure {
   }
 
   $self->add_plugins(
-    [ PkgVersion => { die_on_existing_version => 1 } ],
+    [
+      PkgVersion => {
+        die_on_existing_version => 1,
+        die_on_line_insertion   => 1,
+      },
+    ],
     qw(
       MetaConfig
       MetaJSON
@@ -210,7 +213,7 @@ Dist::Zilla::PluginBundle::RJBS - BeLike::RJBS when you build your dists
 
 =head1 VERSION
 
-version 5.002
+version 5.003
 
 =head1 DESCRIPTION
 
@@ -224,6 +227,7 @@ This is the plugin bundle that RJBS uses.  It is more or less equivalent to:
   [Git::NextVersion]
   [PkgVersion]
   die_on_existing_version = 1
+  die_on_line_insertion   = 1
   [MetaConfig]
   [MetaJSON]
   [NextRelease]
